==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ExtendedErrorInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ExtendedErrorInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property additionalInfo
 * @property code
 * @property details
 * @property message
 * @property target
 */
public data class ExtendedErrorInfoArgs(
    public val additionalInfo: Output<List<TypedErrorInfoArgs>>? = null,
    public val code: Output<String>? = null,
    public val details: Output<List<ExtendedErrorInfoArgs>>? = null,
    public val message: Output<String>? = null,
    public val target: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ExtendedErrorInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.ExtendedErrorInfoArgs =
        com.pulumi.azurenative.providerhub.inputs.ExtendedErrorInfoArgs.builder()
            .additionalInfo(
                additionalInfo?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .code(code?.applyValue({ args0 -> args0 }))
            .details(
                details?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .message(message?.applyValue({ args0 -> args0 }))
            .target(target?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExtendedErrorInfoArgs].
 */
@PulumiTagMarker
public class ExtendedErrorInfoArgsBuilder internal constructor() {
    private var additionalInfo: Output<List<TypedErrorInfoArgs>>? = null

    private var code: Output<String>? = null

    private var details: Output<List<ExtendedErrorInfoArgs>>? = null

    private var message: Output<String>? = null

    private var target: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("lflhbvfkermvdrgr")
    public suspend fun additionalInfo(`value`: Output<List<TypedErrorInfoArgs>>) {
        this.additionalInfo = value
    }

    @JvmName("rebxyjfntftynxgu")
    public suspend fun additionalInfo(vararg values: Output<TypedErrorInfoArgs>) {
        this.additionalInfo = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("stqgqibrenqqixcj")
    public suspend fun additionalInfo(values: List<Output<TypedErrorInfoArgs>>) {
        this.additionalInfo = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ykaeaqwlqqefpksf")
    public suspend fun code(`value`: Output<String>) {
        this.code = value
    }

    /**
     * @param value
     */
    @JvmName("hoohqpgydclfltxf")
    public suspend fun details(`value`: Output<List<ExtendedErrorInfoArgs>>) {
        this.details = value
    }

    @JvmName("mxdonnpesrfbyxqo")
    public suspend fun details(vararg values: Output<ExtendedErrorInfoArgs>) {
        this.details = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("kkyvlppsrljbpvea")
    public suspend fun details(values: List<Output<ExtendedErrorInfoArgs>>) {
        this.details = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ltwxkmtulkdswylt")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value
     */
    @JvmName("drueiptmachmtwxp")
    public suspend fun target(`value`: Output<String>) {
        this.target = value
    }

    /**
     * @param value
     */
    @JvmName("dlsbeuvlgwpjdxdu")
    public suspend fun additionalInfo(`value`: List<TypedErrorInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalInfo = mapped
    }

    /**
     * @param argument
     */
    @JvmName("odhresoilrcdynor")
    public suspend fun additionalInfo(argument: List<suspend TypedErrorInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TypedErrorInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.additionalInfo = mapped
    }

    /**
     * @param argument
     */
    @JvmName("litwthgbhshgmpfb")
    public suspend fun additionalInfo(vararg argument: suspend TypedErrorInfoArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TypedErrorInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.additionalInfo = mapped
    }

    /**
     * @param argument
     */
    @JvmName("qhgugwnovmldbofs")
    public suspend fun additionalInfo(argument: suspend TypedErrorInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TypedErrorInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.additionalInfo = mapped
    }

    /**
     * @param values
     */
    @JvmName("sbliknymjxynpfcp")
    public suspend fun additionalInfo(vararg values: TypedErrorInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalInfo = mapped
    }

    /**
     * @param value
     */
    @JvmName("bwokmygnaxbltqto")
    public suspend fun code(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value
     */
    @JvmName("awnydawkspjchrel")
    public suspend fun details(`value`: List<ExtendedErrorInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.details = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tkmoesbiiqeboimf")
    public suspend fun details(argument: List<suspend ExtendedErrorInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ExtendedErrorInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.details = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kaijyicpdsndtpkh")
    public suspend fun details(vararg argument: suspend ExtendedErrorInfoArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ExtendedErrorInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.details = mapped
    }

    /**
     * @param argument
     */
    @JvmName("slrcsvjhvxeoxwsc")
    public suspend fun details(argument: suspend ExtendedErrorInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ExtendedErrorInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.details = mapped
    }

    /**
     * @param values
     */
    @JvmName("ycafvqtaqcklkcnf")
    public suspend fun details(vararg values: ExtendedErrorInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.details = mapped
    }

    /**
     * @param value
     */
    @JvmName("edqsuogvbbrnlgbj")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value
     */
    @JvmName("ibbvgmwleeltpngw")
    public suspend fun target(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    internal fun build(): ExtendedErrorInfoArgs = ExtendedErrorInfoArgs(
        additionalInfo = additionalInfo,
        code = code,
        details = details,
        message = message,
        target = target,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ExtendedErrorInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ExtendedErrorInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property additionalInfo
 * @property code
 * @property details
 * @property message
 * @property target
 */
public data class ExtendedErrorInfoArgs(
    public val additionalInfo: Output<List<TypedErrorInfoArgs>>? = null,
    public val code: Output<String>? = null,
    public val details: Output<List<ExtendedErrorInfoArgs>>? = null,
    public val message: Output<String>? = null,
    public val target: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ExtendedErrorInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.ExtendedErrorInfoArgs =
        com.pulumi.azurenative.providerhub.inputs.ExtendedErrorInfoArgs.builder()
            .additionalInfo(
                additionalInfo?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .code(code?.applyValue({ args0 -> args0 }))
            .details(
                details?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .message(message?.applyValue({ args0 -> args0 }))
            .target(target?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExtendedErrorInfoArgs].
 */
@PulumiTagMarker
public class ExtendedErrorInfoArgsBuilder internal constructor() {
    private var additionalInfo: Output<List<TypedErrorInfoArgs>>? = null

    private var code: Output<String>? = null

    private var details: Output<List<ExtendedErrorInfoArgs>>? = null

    private var message: Output<String>? = null

    private var target: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("pshiyohuppmtnsvb")
    public suspend fun additionalInfo(`value`: Output<List<TypedErrorInfoArgs>>) {
        this.additionalInfo = value
    }

    @JvmName("otdinqtberorlkgd")
    public suspend fun additionalInfo(vararg values: Output<TypedErrorInfoArgs>) {
        this.additionalInfo = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("lvkotybrckxymdxi")
    public suspend fun additionalInfo(values: List<Output<TypedErrorInfoArgs>>) {
        this.additionalInfo = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ykeptsjfqxhbhmhk")
    public suspend fun code(`value`: Output<String>) {
        this.code = value
    }

    /**
     * @param value
     */
    @JvmName("paadwdivnlggjlum")
    public suspend fun details(`value`: Output<List<ExtendedErrorInfoArgs>>) {
        this.details = value
    }

    @JvmName("hcatuyondfiyinas")
    public suspend fun details(vararg values: Output<ExtendedErrorInfoArgs>) {
        this.details = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("rpmcfopensqrkvju")
    public suspend fun details(values: List<Output<ExtendedErrorInfoArgs>>) {
        this.details = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("dqevtfohieusfwws")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value
     */
    @JvmName("ladptkwjonmeyeng")
    public suspend fun target(`value`: Output<String>) {
        this.target = value
    }

    /**
     * @param value
     */
    @JvmName("mgspisjvvxjoccbk")
    public suspend fun additionalInfo(`value`: List<TypedErrorInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalInfo = mapped
    }

    /**
     * @param argument
     */
    @JvmName("unjalhscbnpvkyfu")
    public suspend fun additionalInfo(argument: List<suspend TypedErrorInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TypedErrorInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.additionalInfo = mapped
    }

    /**
     * @param argument
     */
    @JvmName("pwrcbeuvsxobyasp")
    public suspend fun additionalInfo(vararg argument: suspend TypedErrorInfoArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TypedErrorInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.additionalInfo = mapped
    }

    /**
     * @param argument
     */
    @JvmName("lfylwryrpimihxwf")
    public suspend fun additionalInfo(argument: suspend TypedErrorInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TypedErrorInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.additionalInfo = mapped
    }

    /**
     * @param values
     */
    @JvmName("wtygkrxnpnxuwhex")
    public suspend fun additionalInfo(vararg values: TypedErrorInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalInfo = mapped
    }

    /**
     * @param value
     */
    @JvmName("bnjdlptukgdxcqxf")
    public suspend fun code(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value
     */
    @JvmName("pyvgstitdivwatgj")
    public suspend fun details(`value`: List<ExtendedErrorInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.details = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ljaqyyumeqtjowmp")
    public suspend fun details(argument: List<suspend ExtendedErrorInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ExtendedErrorInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.details = mapped
    }

    /**
     * @param argument
     */
    @JvmName("malowfexxjpgakub")
    public suspend fun details(vararg argument: suspend ExtendedErrorInfoArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ExtendedErrorInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.details = mapped
    }

    /**
     * @param argument
     */
    @JvmName("qrtwykdnslwrlwsp")
    public suspend fun details(argument: suspend ExtendedErrorInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ExtendedErrorInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.details = mapped
    }

    /**
     * @param values
     */
    @JvmName("exlymcqpqqptnrdm")
    public suspend fun details(vararg values: ExtendedErrorInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.details = mapped
    }

    /**
     * @param value
     */
    @JvmName("tfcrfdwcrpfvrhfy")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value
     */
    @JvmName("jhjsbhiqgmnxjkfp")
    public suspend fun target(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    internal fun build(): ExtendedErrorInfoArgs = ExtendedErrorInfoArgs(
        additionalInfo = additionalInfo,
        code = code,
        details = details,
        message = message,
        target = target,
    )
}
